@@ -27,8 +27,6 @@
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusInterface>
 
-#include <kdemacros.h>
-
 #include "upower_device_interface.h"
 #include "upower_interface.h"
 #include "upower_kbdbacklight_interface.h"
@@ -59,7 +57,7 @@ public:
     virtual int brightnessValue(BrightnessControlType type = Screen) const;
     virtual int brightnessValueMax(BrightnessControlType type = Screen) const;
 
-    virtual void brightnessKeyPressed(PowerDevil::BackendInterface::BrightnessKeyType type, PowerDevil::BackendInterface::BrightnessControlType controlType);
+    virtual void brightnessKeyPressed(PowerDevil::BrightnessLogic::BrightnessKeyType type, BrightnessControlType controlType);
     virtual bool setBrightnessValue(int brightnessValue, PowerDevil::BackendInterface::BrightnessControlType type = Screen);
     virtual KJob* suspend(PowerDevil::BackendInterface::SuspendMethod method);
 
@@ -88,7 +86,7 @@ private:
     QMap<QString, OrgFreedesktopUPowerDeviceInterface *> m_devices;
 
     // brightness
-    QMap<BrightnessControlType, float> m_cachedBrightnessMap;
+    QMap<BrightnessControlType, int> m_cachedBrightnessMap;
     XRandrBrightness         *m_brightnessControl;
     XRandRXCBHelper *m_randrHelper;
 
